ProductVariant class

Annotations
  • @freezed

Constructors

ProductVariant({String? size, String? color, required double price})
factory
ProductVariant.fromJson(Map<String, Object?> json)
factory

Properties

color → String?
no setterinherited
copyWith → $ProductVariantCopyWith<ProductVariant>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
price → double
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited